Crate rs_graph[−][src]
A library for basic graph data structures and algorithms.
Re-exports
pub use self::traits::Digraph; | |
pub use self::traits::Graph; | |
pub use self::traits::IndexDigraph; | |
pub use self::traits::IndexGraph; | |
pub use self::traits::NumberedDigraph; | |
pub use self::traits::NumberedGraph; | |
pub use self::adapters::Network; | |
pub use crate::builder::Buildable; | |
pub use crate::builder::Builder; | |
pub use self::linkedlistgraph::LinkedListGraph; | |
pub use self::vecgraph::VecGraph; | |
pub use self::attributes::AttributedGraph; | |
pub use self::attributes::EdgeAttributes; | |
pub use self::attributes::NodeAttributes; | |
pub use crate::vec::EdgeVec; | |
pub use crate::vec::NodeVec; |
Modules
| adapters | |
| adjacencies | Abstraction of neighboring edges. |
| algorithms | General algorithms working on graphs. |
| attributed | Deprecated Extend a graph with attributes. |
| attributes | Extend a graph with attributes. |
| branching | Compute a maximum weight branching. |
| builder | Traits for constructing graphs. |
| classes | Graph classes Some common graph classes. |
| collections | |
| dimacs | Reading files in DIMACS format. |
| draw | Visualizing graphs. |
| filtered | This is a graph adaptor suppressing some edges. |
| linkedlistgraph | A linked-list based graph implementation. |
| maxflow | Maximum Network Flow algorithms. |
| mcf | |
| mst | Minimum spanning tree algorithms. |
| search | Graph search algorithms. |
| shortestpath | Shortest path algorithms. |
| steinlib | Reading files in |
| string | |
| traits | Traits for graph data structures. |
| vec | This module provides vectors that can be indexed by nodes, edges or arcs. |
| vecgraph |
Structs
| ReverseDigraph | A digraph wrapping an existing graph with edges in opposite directions. |
Functions
| reverse |
Type Definitions
| Net | The default graph type. |